@@ -20,28 +20,21 @@
 
 #include "knoteedit.h"
 #include "notes/knote.h"
-#include "config/noteactionconfig.h"
-#include "KPIMTextEdit/EditorUtil"
-#include "PimCommon/KActionMenuChangeCase"
-#include "knotesglobalconfig.h"
+#include "editor/noteeditorutils.h"
 
-#include <QAction>
+#include <KPIMTextEdit/EditorUtil>
 
-#include <kactioncollection.h>
-#include <QColorDialog>
-#include "knotes_debug.h"
-#include <kfontaction.h>
-#include <kfontsizeaction.h>
+#include <PimCommon/KActionMenuChangeCase>
+
+#include <KActionCollection>
+#include <KFontAction>
+#include <KFontSizeAction>
 #include <KLocalizedString>
+#include <KToggleAction>
+
+#include <QColorDialog>
+#include <QIcon>
 #include <QMenu>
-#include <kstandardaction.h>
-#include <ktoggleaction.h>
-
-#include <QFont>
-#include <QPixmap>
-#include <QKeyEvent>
-
-#include <editor/noteeditorutils.h>
 
 static const short ICON_SIZE = 10;
 
@@ -126,15 +119,13 @@ KNoteEdit::KNoteEdit(KActionCollection *actions, QWidget *parent)
     m_textIncreaseIndent = new QAction(QIcon::fromTheme(QStringLiteral("format-indent-more")),
                                        i18n("Increase Indent"), this);
     actions->addAction(QStringLiteral("format_increaseindent"), m_textIncreaseIndent);
-    actions->setDefaultShortcut(m_textIncreaseIndent, QKeySequence(Qt::CTRL + Qt::ALT
-                                                                   +Qt::Key_I));
+    actions->setDefaultShortcut(m_textIncreaseIndent, QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_I));
     connect(m_textIncreaseIndent, &QAction::triggered, this, &KNoteEdit::textIncreaseIndent);
 
     m_textDecreaseIndent = new QAction(QIcon::fromTheme(QStringLiteral("format-indent-less")),
                                        i18n("Decrease Indent"), this);
     actions->addAction(QStringLiteral("format_decreaseindent"), m_textDecreaseIndent);
-    actions->setDefaultShortcut(m_textDecreaseIndent, QKeySequence(Qt::CTRL + Qt::ALT
-                                                                   +Qt::Key_D));
+    actions->setDefaultShortcut(m_textDecreaseIndent, QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_D));
     connect(m_textDecreaseIndent, &QAction::triggered, this, &KNoteEdit::textDecreaseIndent);
 
     group = new QActionGroup(this);
@@ -148,13 +139,14 @@ KNoteEdit::KNoteEdit(KActionCollection *actions, QWidget *parent)
     m_textColor->setIcon(pix);
     connect(m_textColor, &QAction::triggered, this, &KNoteEdit::slotTextColor);
 
-    QAction *act = new QAction(QIcon::fromTheme(QStringLiteral("format-fill-color")), i18n("Text Background Color..."), this);
+    QAction *act = new QAction(QIcon::fromTheme(QStringLiteral("format-fill-color")),
+                               i18n("Text Background Color..."), this);
     actions->addAction(QStringLiteral("text_background_color"), act);
     connect(act, &QAction::triggered, this, &KNoteEdit::slotTextBackgroundColor);
 
     m_textFont = new KFontAction(i18n("Text Font"), this);
     actions->addAction(QStringLiteral("format_font"), m_textFont);
-    connect(m_textFont, static_cast<void (KFontAction::*)(const QString &)>(&KFontAction::triggered), this, &KNoteEdit::setFontFamily);
+    connect(m_textFont, QOverload<const QString &>::of(&KFontAction::triggered), this, &KNoteEdit::setFontFamily);
 
     m_textSize = new KFontSizeAction(i18n("Text Size"), this);
     actions->addAction(QStringLiteral("format_size"), m_textSize);
@@ -196,7 +188,7 @@ void KNoteEdit::setColor(const QColor &fg, const QColor &bg)
     // better: from light(150) to light(100) to light(75)
     // QLinearGradient g( width()/2, 0, width()/2, height() );
     // g.setColorAt( 0, bg );
-    // g.setColorAt( 1, bg.dark(150) );
+    // g.setColorAt( 1, bg.darker(150) );
 
     p.setColor(QPalette::Window, bg);
     // p.setBrush( QPalette::Window,     g );
@@ -206,7 +198,7 @@ void KNoteEdit::setColor(const QColor &fg, const QColor &bg)
     p.setColor(QPalette::WindowText, fg);
     p.setColor(QPalette::Text, fg);
 
-    p.setColor(QPalette::Button, bg.dark(116));
+    p.setColor(QPalette::Button, bg.darker(116));
     p.setColor(QPalette::ButtonText, fg);
 
     //p.setColor( QPalette::Highlight,  bg );
@@ -215,11 +207,11 @@ void KNoteEdit::setColor(const QColor &fg, const QColor &bg)
     // order: Light, Midlight, Button, Mid, Dark, Shadow
 
     // the shadow
-    p.setColor(QPalette::Light, bg.light(180));
-    p.setColor(QPalette::Midlight, bg.light(150));
-    p.setColor(QPalette::Mid, bg.light(150));
-    p.setColor(QPalette::Dark, bg.dark(108));
-    p.setColor(QPalette::Shadow, bg.dark(116));
+    p.setColor(QPalette::Light, bg.lighter(180));
+    p.setColor(QPalette::Midlight, bg.lighter(150));
+    p.setColor(QPalette::Mid, bg.lighter(150));
+    p.setColor(QPalette::Dark, bg.darker(108));
+    p.setColor(QPalette::Shadow, bg.darker(116));
 
     setPalette(p);
 
@@ -404,7 +396,7 @@ void KNoteEdit::slotTextBackgroundColor()
     if (m_note) {
         m_note->setBlockSave(true);
     }
-    QColor c = QColorDialog::getColor(textBackgroundColor(), this);
+    const QColor c = QColorDialog::getColor(textBackgroundColor(), this);
     if (c.isValid()) {
         setTextBackgroundColor(c);
     }
@@ -541,8 +533,7 @@ void KNoteEdit::keyPressEvent(QKeyEvent *e)
 {
     KTextEdit::keyPressEvent(e);
 
-    if (m_autoIndentMode
-        && ((e->key() == Qt::Key_Return) || (e->key() == Qt::Key_Enter))) {
+    if (m_autoIndentMode && ((e->key() == Qt::Key_Return) || (e->key() == Qt::Key_Enter))) {
         autoIndent();
     }
 }
